@@ -17,11 +17,13 @@ Algorithm::Easing - Calculate eased translations between two positive whole inte
 
         ## with mediator
 
-        require Algorithm::Easing;
+        use Algorithm::Easing;
+        use Algorithm::Easing::Mediator;
+        use Algorithm::Easing::Bounce;
 
         # this example produces traditional 'bounce' output;
 
-        my $bounce_translation = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::BOUNCE);
+        my $bounce_translation = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::Bounce->new);
 
         # total time for eased translation as a real positive integer value
         my $d = 2.5;
@@ -70,11 +72,13 @@ Read of a usage example using the proper mediator :
 
     ## with mediator
 
-    require Algorithm::Easing;
+    use Algorithm::Easing;
+    use Algorithm::Easing::Mediator;
+    use Algorithm::Easing::Bounce;
 
     # this example produces traditional 'bounce' output;
 
-    my $bounce_translation = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::BOUNCE);
+    my $bounce_translation = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::Bounce->new);
 
     # total time for eased translation as a real positive integer value
     my $t = 2.5;
